summaryrefslogtreecommitdiffstats
path: root/krdc/krdc.h
diff options
context:
space:
mode:
Diffstat (limited to 'krdc/krdc.h')
-rw-r--r--krdc/krdc.h78
1 files changed, 39 insertions, 39 deletions
diff --git a/krdc/krdc.h b/krdc/krdc.h
index 5bf9a4bd..a5925540 100644
--- a/krdc/krdc.h
+++ b/krdc/krdc.h
@@ -19,12 +19,12 @@
#define KRDC_H
#include <kprogress.h>
-#include <qscrollview.h>
-#include <qlayout.h>
-#include <qsize.h>
-#include <qrect.h>
-#include <qtimer.h>
-#include <qdesktopwidget.h>
+#include <tqscrollview.h>
+#include <tqlayout.h>
+#include <tqsize.h>
+#include <tqrect.h>
+#include <tqtimer.h>
+#include <tqdesktopwidget.h>
#include "vnc/kvncview.h"
#include "rdp/krdpview.h"
@@ -51,12 +51,12 @@ enum Protocol {
PROTOCOL_RDP
};
-// Overloaded QScrollView, to let mouse move events through to remote widget
-class QScrollView2 : public QScrollView {
+// Overloaded TQScrollView, to let mouse move events through to remote widget
+class QScrollView2 : public TQScrollView {
public:
- QScrollView2(QWidget *w, const char *name);
+ QScrollView2(TQWidget *w, const char *name);
protected:
- virtual void mouseMoveEvent(QMouseEvent *e);
+ virtual void mouseMoveEvent(TQMouseEvent *e);
};
@@ -65,51 +65,51 @@ class KRDC : public QWidget
Q_OBJECT
private:
SmartPtr<KProgressDialog> m_progressDialog; // dialog, displayed while connecting
- QVBoxLayout *m_layout; // the layout for autosizing the scrollview
- QScrollView *m_scrollView; // scrollview that contains the remote widget
+ TQVBoxLayout *m_layout; // the layout for autosizing the scrollview
+ TQScrollView *m_scrollView; // scrollview that contains the remote widget
KProgress *m_progress; // progress bar for the dialog
KRemoteView *m_view; // the remote widget (e.g. KVncView)
SmartPtr<KeyCaptureDialog> m_keyCaptureDialog; // dialog for key capturing
KFullscreenPanel *m_fsToolbar; // toolbar for fullscreen (0 in normal mode)
- QWidget *m_fsToolbarWidget; // qt designer widget for fs toolbar
+ TQWidget *m_fsToolbarWidget; // qt designer widget for fs toolbar
// (invalid in normal mode)
- QPixmap m_pinup, m_pindown; // fs toolbar imaged for autohide button
+ TQPixmap m_pinup, m_pindown; // fs toolbar imaged for autohide button
KToolBar *m_toolbar; // toolbar in normal mode (0 in fs mode)
- QDockArea *m_dockArea; // dock area for toolbar in normal mode (0 in fs mode)
- QPopupMenu *m_popup; // advanced options popup (0 in fs mode)
- QDesktopWidget m_desktopWidget;
+ TQDockArea *m_dockArea; // dock area for toolbar in normal mode (0 in fs mode)
+ TQPopupMenu *m_popup; // advanced options popup (0 in fs mode)
+ TQDesktopWidget m_desktopWidget;
static const int TOOLBAR_AUTOHIDE_TIMEOUT;
bool m_ftAutoHide; // if true auto hide in fs is activated
- QTimer m_autoHideTimer; // timer for autohide
+ TQTimer m_autoHideTimer; // timer for autohide
- QTimer m_bumpScrollTimer; // timer for bump scrolling (in fs, when res too large)
+ TQTimer m_bumpScrollTimer; // timer for bump scrolling (in fs, when res too large)
bool m_showProgress; // can disable showing the progress dialog temporary
- QString m_host; // host string as given from user
+ TQString m_host; // host string as given from user
Protocol m_protocol; // the used protocol
Quality m_quality; // current quality setting
- QString m_encodings; // string containing the encodings, space separated,
+ TQString m_encodings; // string containing the encodings, space separated,
// used for config before connection
- QString m_password; // if not null, contains the password to use
- QString m_resolution;// contains an alternative resolution
- QString m_keymap; // keymap on the terminal server
+ TQString m_password; // if not null, contains the password to use
+ TQString m_resolution;// contains an alternative resolution
+ TQString m_keymap; // keymap on the terminal server
WindowMode m_isFullscreen; // fs/normal state
Resolution m_oldResolution; // conatins encoded res before fs
bool m_fullscreenMinimized; // true if window is currently minimized from fs
- QSize m_fullscreenResolution; // xvidmode size (valid only in fs)
+ TQSize m_fullscreenResolution; // xvidmode size (valid only in fs)
bool m_windowScaling; // used in startup and fullscreen to determine
// whether scaling should be enabled in norm mode.
// The current state is m_view->scaled().
bool m_localCursor; // show local cursor no matter what
- QSize m_initialWindowSize; // initial window size (windowed mode only),
+ TQSize m_initialWindowSize; // initial window size (windowed mode only),
// invalid after first use
- static QString m_lastHost; // remembers last value of host input
+ static TQString m_lastHost; // remembers last value of host input
- bool parseHost(QString &s, Protocol &prot, QString &serverHost, int &serverPort,
- QString &userName, QString &password);
+ bool parseHost(TQString &s, Protocol &prot, TQString &serverHost, int &serverPort,
+ TQString &userName, TQString &password);
void repositionView(bool fullscreen);
@@ -120,28 +120,28 @@ private:
static const int TOOLBAR_SPEED_DOWN;
static const int TOOLBAR_SPEED_UP;
void fsToolbarScheduleHidden();
- QPopupMenu *createPopupMenu(QWidget *parent) const;
+ TQPopupMenu *createPopupMenu(TQWidget *parent) const;
protected:
- virtual void mouseMoveEvent(QMouseEvent *e);
- virtual bool event(QEvent *e);
- virtual bool eventFilter(QObject *watched, QEvent *e);
- virtual QSize sizeHint();
+ virtual void mouseMoveEvent(TQMouseEvent *e);
+ virtual bool event(TQEvent *e);
+ virtual bool eventFilter(TQObject *watched, TQEvent *e);
+ virtual TQSize sizeHint();
public:
KRDC(WindowMode wm = WINDOW_MODE_AUTO,
- const QString &host = QString::null,
+ const TQString &host = TQString::null,
Quality q = QUALITY_UNKNOWN,
- const QString &encodings = QString::null,
- const QString &password = QString::null,
+ const TQString &encodings = TQString::null,
+ const TQString &password = TQString::null,
bool scale = false,
bool localCursor = false,
- QSize initialWindowSize = QSize());
+ TQSize initialWindowSize = TQSize());
~KRDC();
bool start();
- static void setLastHost(const QString &host);
+ static void setLastHost(const TQString &host);
private slots:
void changeProgress(RemoteViewStatus s);